@@ -663,7 +663,8 @@ class Project(DataClassJSONMixin):
 
         try:
             upgradable_paths = filter(
-                lambda path: path[0].fixVersion is not None, issue_paths.paths,
+                lambda path: path[0].fixVersion is not None,
+                issue_paths.paths,
             )
             first_path = next(upgradable_paths)
             upgrade_path = list(map(format_package, first_path))
